@@ -303,6 +303,10 @@ thunar_dialogs_show_error (gpointer      parent,
 
   _thunar_return_if_fail (parent == NULL || GDK_IS_SCREEN (parent) || GTK_IS_WIDGET (parent));
 
+  /* do not display error dialog for already handled errors */
+  if (error->code == G_IO_ERROR_FAILED_HANDLED)
+    return;
+
   /* parse the parent pointer */
   screen = thunar_util_parse_parent (parent, &window);
 
