@@ -179,7 +179,7 @@ thunar_dnd_ask (GtkWidget    *widget,
 
   /* cleanup */
   g_object_unref (G_OBJECT (factory));
-  g_list_free (file_list);
+  g_list_free_full (file_list, g_object_unref);
 
   return dnd_action;
 }
@@ -247,7 +247,7 @@ thunar_dnd_perform (GtkWidget    *widget,
   else if (thunar_file_is_executable (file))
     {
       /* TODO any chance to determine the working dir here? */
-      succeed = thunar_file_execute (file, NULL, widget, file_list, &error);
+      succeed = thunar_file_execute (file, NULL, widget, file_list, NULL, &error);
       if (G_UNLIKELY (!succeed))
         {
           /* display an error to the user */
