@@ -50,7 +50,46 @@
 #endif /* !G_ENABLE_DEBUG */
 
 
-/* BOOLEAN:POINTER (thunar-marshal.list:1) */
+/* BOOLEAN:BOOLEAN (thunar-marshal.list:1) */
+void
+_thunar_marshal_BOOLEAN__BOOLEAN (GClosure     *closure,
+                                  GValue       *return_value G_GNUC_UNUSED,
+                                  guint         n_param_values,
+                                  const GValue *param_values,
+                                  gpointer      invocation_hint G_GNUC_UNUSED,
+                                  gpointer      marshal_data)
+{
+  typedef gboolean (*GMarshalFunc_BOOLEAN__BOOLEAN) (gpointer     data1,
+                                                     gboolean     arg_1,
+                                                     gpointer     data2);
+  GMarshalFunc_BOOLEAN__BOOLEAN callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
+  gboolean v_return;
+
+  g_return_if_fail (return_value != NULL);
+  g_return_if_fail (n_param_values == 2);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_BOOLEAN__BOOLEAN) (marshal_data ? marshal_data : cc->callback);
+
+  v_return = callback (data1,
+                       g_marshal_value_peek_boolean (param_values + 1),
+                       data2);
+
+  g_value_set_boolean (return_value, v_return);
+}
+
+/* BOOLEAN:POINTER (thunar-marshal.list:2) */
 void
 _thunar_marshal_BOOLEAN__POINTER (GClosure     *closure,
                                   GValue       *return_value G_GNUC_UNUSED,
@@ -62,9 +101,9 @@ _thunar_marshal_BOOLEAN__POINTER (GClosure     *closure,
   typedef gboolean (*GMarshalFunc_BOOLEAN__POINTER) (gpointer     data1,
                                                      gpointer     arg_1,
                                                      gpointer     data2);
-  register GMarshalFunc_BOOLEAN__POINTER callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_BOOLEAN__POINTER callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   gboolean v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -89,7 +128,7 @@ _thunar_marshal_BOOLEAN__POINTER (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:VOID (thunar-marshal.list:2) */
+/* BOOLEAN:VOID (thunar-marshal.list:3) */
 void
 _thunar_marshal_BOOLEAN__VOID (GClosure     *closure,
                                GValue       *return_value G_GNUC_UNUSED,
@@ -100,9 +139,9 @@ _thunar_marshal_BOOLEAN__VOID (GClosure     *closure,
 {
   typedef gboolean (*GMarshalFunc_BOOLEAN__VOID) (gpointer     data1,
                                                   gpointer     data2);
-  register GMarshalFunc_BOOLEAN__VOID callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_BOOLEAN__VOID callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   gboolean v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -126,7 +165,7 @@ _thunar_marshal_BOOLEAN__VOID (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:INT (thunar-marshal.list:3) */
+/* BOOLEAN:INT (thunar-marshal.list:4) */
 void
 _thunar_marshal_BOOLEAN__INT (GClosure     *closure,
                               GValue       *return_value G_GNUC_UNUSED,
@@ -138,9 +177,9 @@ _thunar_marshal_BOOLEAN__INT (GClosure     *closure,
   typedef gboolean (*GMarshalFunc_BOOLEAN__INT) (gpointer     data1,
                                                  gint         arg_1,
                                                  gpointer     data2);
-  register GMarshalFunc_BOOLEAN__INT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_BOOLEAN__INT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   gboolean v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -165,7 +204,7 @@ _thunar_marshal_BOOLEAN__INT (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* FLAGS:OBJECT,OBJECT (thunar-marshal.list:4) */
+/* FLAGS:OBJECT,OBJECT (thunar-marshal.list:5) */
 void
 _thunar_marshal_FLAGS__OBJECT_OBJECT (GClosure     *closure,
                                       GValue       *return_value G_GNUC_UNUSED,
@@ -178,9 +217,9 @@ _thunar_marshal_FLAGS__OBJECT_OBJECT (GClosure     *closure,
                                                       gpointer     arg_1,
                                                       gpointer     arg_2,
                                                       gpointer     data2);
-  register GMarshalFunc_FLAGS__OBJECT_OBJECT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_FLAGS__OBJECT_OBJECT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   guint v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -206,7 +245,7 @@ _thunar_marshal_FLAGS__OBJECT_OBJECT (GClosure     *closure,
   g_value_set_flags (return_value, v_return);
 }
 
-/* FLAGS:STRING,FLAGS (thunar-marshal.list:5) */
+/* FLAGS:STRING,FLAGS (thunar-marshal.list:6) */
 void
 _thunar_marshal_FLAGS__STRING_FLAGS (GClosure     *closure,
                                      GValue       *return_value G_GNUC_UNUSED,
@@ -219,9 +258,9 @@ _thunar_marshal_FLAGS__STRING_FLAGS (GClosure     *closure,
                                                      gpointer     arg_1,
                                                      guint        arg_2,
                                                      gpointer     data2);
-  register GMarshalFunc_FLAGS__STRING_FLAGS callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_FLAGS__STRING_FLAGS callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   guint v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -247,7 +286,7 @@ _thunar_marshal_FLAGS__STRING_FLAGS (GClosure     *closure,
   g_value_set_flags (return_value, v_return);
 }
 
-/* VOID:STRING,STRING (thunar-marshal.list:6) */
+/* VOID:STRING,STRING (thunar-marshal.list:7) */
 void
 _thunar_marshal_VOID__STRING_STRING (GClosure     *closure,
                                      GValue       *return_value G_GNUC_UNUSED,
@@ -260,9 +299,9 @@ _thunar_marshal_VOID__STRING_STRING (GClosure     *closure,
                                                     gpointer     arg_1,
                                                     gpointer     arg_2,
                                                     gpointer     data2);
-  register GMarshalFunc_VOID__STRING_STRING callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__STRING_STRING callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -284,7 +323,7 @@ _thunar_marshal_VOID__STRING_STRING (GClosure     *closure,
             data2);
 }
 
-/* VOID:UINT64,UINT,UINT,UINT (thunar-marshal.list:7) */
+/* VOID:UINT64,UINT,UINT,UINT (thunar-marshal.list:8) */
 void
 _thunar_marshal_VOID__UINT64_UINT_UINT_UINT (GClosure     *closure,
                                              GValue       *return_value G_GNUC_UNUSED,
@@ -299,9 +338,9 @@ _thunar_marshal_VOID__UINT64_UINT_UINT_UINT (GClosure     *closure,
                                                             guint        arg_3,
                                                             guint        arg_4,
                                                             gpointer     data2);
-  register GMarshalFunc_VOID__UINT64_UINT_UINT_UINT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__UINT64_UINT_UINT_UINT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 5);
 
@@ -325,7 +364,7 @@ _thunar_marshal_VOID__UINT64_UINT_UINT_UINT (GClosure     *closure,
             data2);
 }
 
-/* VOID:UINT,BOXED,UINT,STRING (thunar-marshal.list:8) */
+/* VOID:UINT,BOXED,UINT,STRING (thunar-marshal.list:9) */
 void
 _thunar_marshal_VOID__UINT_BOXED_UINT_STRING (GClosure     *closure,
                                               GValue       *return_value G_GNUC_UNUSED,
@@ -340,9 +379,9 @@ _thunar_marshal_VOID__UINT_BOXED_UINT_STRING (GClosure     *closure,
                                                              guint        arg_3,
                                                              gpointer     arg_4,
                                                              gpointer     data2);
-  register GMarshalFunc_VOID__UINT_BOXED_UINT_STRING callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__UINT_BOXED_UINT_STRING callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 5);
 
@@ -366,7 +405,7 @@ _thunar_marshal_VOID__UINT_BOXED_UINT_STRING (GClosure     *closure,
             data2);
 }
 
-/* VOID:UINT,BOXED (thunar-marshal.list:9) */
+/* VOID:UINT,BOXED (thunar-marshal.list:10) */
 void
 _thunar_marshal_VOID__UINT_BOXED (GClosure     *closure,
                                   GValue       *return_value G_GNUC_UNUSED,
@@ -379,9 +418,9 @@ _thunar_marshal_VOID__UINT_BOXED (GClosure     *closure,
                                                  guint        arg_1,
                                                  gpointer     arg_2,
                                                  gpointer     data2);
-  register GMarshalFunc_VOID__UINT_BOXED callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__UINT_BOXED callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -403,7 +442,7 @@ _thunar_marshal_VOID__UINT_BOXED (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT,OBJECT (thunar-marshal.list:10) */
+/* VOID:OBJECT,OBJECT (thunar-marshal.list:11) */
 void
 _thunar_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
                                      GValue       *return_value G_GNUC_UNUSED,
@@ -416,9 +455,9 @@ _thunar_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
                                                     gpointer     arg_1,
                                                     gpointer     arg_2,
                                                     gpointer     data2);
-  register GMarshalFunc_VOID__OBJECT_OBJECT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_OBJECT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
