@@ -87,6 +87,7 @@ static void     thunar_path_entry_drag_data_get                 (GtkWidget
                                                                  guint                 timestamp);
 static void     thunar_path_entry_activate                      (GtkEntry             *entry);
 static void     thunar_path_entry_changed                       (GtkEditable          *editable);
+static void     thunar_path_entry_update_icon                   (ThunarPathEntry      *path_entry);
 static void     thunar_path_entry_do_insert_text                (GtkEditable          *editable,
                                                                  const gchar          *new_text,
                                                                  gint                  new_text_length,
@@ -387,7 +388,7 @@ thunar_path_entry_button_press_event (GtkWidget      *widget,
       /* consume the event */
       path_entry->drag_button = event->button;
       path_entry->drag_x = event->x;
-      path_entry->drag_x = event->y;
+      path_entry->drag_y = event->y;
       return TRUE;
     }
 
@@ -538,16 +539,14 @@ thunar_path_entry_changed (GtkEditable *editable)
   ThunarFolder       *folder;
   GtkTreeModel       *model;
   const gchar        *text;
+  gchar              *escaped_text;
   ThunarFile         *current_folder;
   ThunarFile         *current_file;
   GFile              *folder_path = NULL;
   GFile              *file_path = NULL;
   gchar              *folder_part = NULL;
   gchar              *file_part = NULL;
-  GdkPixbuf          *icon = NULL;
-  GtkIconTheme       *icon_theme;
   gboolean            update_icon = FALSE;
-  gint                icon_size;
 
   /* check if we should ignore this event */
   if (G_UNLIKELY (path_entry->in_change))
@@ -558,7 +557,9 @@ thunar_path_entry_changed (GtkEditable *editable)
   if (G_UNLIKELY (exo_str_looks_like_an_uri (text)))
     {
       /* try to parse the URI text */
-      file_path = g_file_new_for_uri (text);
+      escaped_text = g_uri_escape_string (text, G_URI_RESERVED_CHARS_ALLOWED_IN_PATH, TRUE);
+      file_path = g_file_new_for_uri (escaped_text);
+      g_free (escaped_text);
 
       /* use the same file if the text assumes we're in a directory */
       if (g_str_has_suffix (text, "/"))
@@ -645,44 +646,7 @@ thunar_path_entry_changed (GtkEditable *editable)
     }
 
   if (update_icon)
-    {
-      if (path_entry->icon_factory == NULL)
-        {
-          icon_theme = gtk_icon_theme_get_for_screen (gtk_widget_get_screen (GTK_WIDGET (path_entry)));
-          path_entry->icon_factory = thunar_icon_factory_get_for_icon_theme (icon_theme);
-        }
-
-      gtk_widget_style_get (GTK_WIDGET (path_entry), "icon-size", &icon_size, NULL);
-
-      if (G_UNLIKELY (path_entry->current_file != NULL))
-        {
-          icon = thunar_icon_factory_load_file_icon (path_entry->icon_factory,
-                                                     path_entry->current_file,
-                                                     THUNAR_FILE_ICON_STATE_DEFAULT,
-                                                     icon_size);
-        }
-      else if (G_LIKELY (path_entry->current_folder != NULL))
-        {
-          icon = thunar_icon_factory_load_file_icon (path_entry->icon_factory,
-                                                     path_entry->current_folder,
-                                                     THUNAR_FILE_ICON_STATE_DEFAULT,
-                                                     icon_size);
-        }
-
-      if (icon != NULL)
-        {
-          gtk_entry_set_icon_from_pixbuf (GTK_ENTRY (path_entry),
-                                          GTK_ENTRY_ICON_PRIMARY,
-                                          icon);
-          g_object_unref (icon);
-        }
-      else
-        {
-          gtk_entry_set_icon_from_icon_name (GTK_ENTRY (path_entry),
-                                             GTK_ENTRY_ICON_PRIMARY,
-                                             GTK_STOCK_DIALOG_ERROR);
-        }
-    }
+    thunar_path_entry_update_icon (path_entry);
 
   /* cleanup */
   if (G_LIKELY (current_folder != NULL))
@@ -696,6 +660,52 @@ thunar_path_entry_changed (GtkEditable *editable)
 }
 
 
+static void
+thunar_path_entry_update_icon (ThunarPathEntry *path_entry)
+{
+  GdkPixbuf          *icon = NULL;
+  GtkIconTheme       *icon_theme;
+  gint                icon_size;
+
+  if (path_entry->icon_factory == NULL)
+    {
+      icon_theme = gtk_icon_theme_get_for_screen (gtk_widget_get_screen (GTK_WIDGET (path_entry)));
+      path_entry->icon_factory = thunar_icon_factory_get_for_icon_theme (icon_theme);
+    }
+
+  gtk_widget_style_get (GTK_WIDGET (path_entry), "icon-size", &icon_size, NULL);
+
+  if (G_UNLIKELY (path_entry->current_file != NULL))
+    {
+      icon = thunar_icon_factory_load_file_icon (path_entry->icon_factory,
+                                                 path_entry->current_file,
+                                                 THUNAR_FILE_ICON_STATE_DEFAULT,
+                                                 icon_size);
+    }
+  else if (G_LIKELY (path_entry->current_folder != NULL))
+    {
+      icon = thunar_icon_factory_load_file_icon (path_entry->icon_factory,
+                                                 path_entry->current_folder,
+                                                 THUNAR_FILE_ICON_STATE_DEFAULT,
+                                                 icon_size);
+    }
+
+  if (icon != NULL)
+    {
+      gtk_entry_set_icon_from_pixbuf (GTK_ENTRY (path_entry),
+                                      GTK_ENTRY_ICON_PRIMARY,
+                                      icon);
+      g_object_unref (icon);
+    }
+  else
+    {
+      gtk_entry_set_icon_from_icon_name (GTK_ENTRY (path_entry),
+                                         GTK_ENTRY_ICON_PRIMARY,
+                                         GTK_STOCK_DIALOG_ERROR);
+    }
+}
+
+
 
 static void
 thunar_path_entry_do_insert_text (GtkEditable *editable,
@@ -1082,7 +1092,7 @@ thunar_path_entry_check_completion_idle (gpointer user_data)
 
   GDK_THREADS_ENTER ();
 
-  /* check if the user entered atleast part of a filename */
+  /* check if the user entered at least part of a filename */
   text = gtk_entry_get_text (GTK_ENTRY (path_entry));
   if (*text != '\0' && text[strlen (text) - 1] != '/')
     {
@@ -1151,10 +1161,11 @@ void
 thunar_path_entry_set_current_file (ThunarPathEntry *path_entry,
                                     ThunarFile      *current_file)
 {
-  GFile *file;
-  gchar *text;
-  gchar *unescaped;
-  gchar *tmp;
+  GFile    *file;
+  gchar    *text;
+  gchar    *unescaped;
+  gchar    *tmp;
+  gboolean  is_uri = FALSE;
 
   _thunar_return_if_fail (THUNAR_IS_PATH_ENTRY (path_entry));
   _thunar_return_if_fail (current_file == NULL || THUNAR_IS_FILE (current_file));
@@ -1175,12 +1186,16 @@ thunar_path_entry_set_current_file (ThunarPathEntry *path_entry,
 
           /* if there is no local path, use the URI (which always works) */
           if (text == NULL)
-            text = g_file_get_uri (file);
+            {
+              text = g_file_get_uri (file);
+              is_uri = TRUE;
+            }
         }
       else
         {
           /* not a native file, use the URI */
           text = g_file_get_uri (file);
+          is_uri = TRUE;
         }
 
       /* if the file is a directory, end with a / to avoid loading the parent
@@ -1194,13 +1209,19 @@ thunar_path_entry_set_current_file (ThunarPathEntry *path_entry,
         }
     }
 
-  unescaped = g_uri_unescape_string (text, NULL);
+  if (is_uri)
+    unescaped = g_uri_unescape_string (text, NULL);
+  else
+    unescaped = g_strdup (text);
   g_free (text);
 
   /* setup the entry text */
   gtk_entry_set_text (GTK_ENTRY (path_entry), unescaped);
   g_free (unescaped);
 
+  /* update the icon */
+  thunar_path_entry_update_icon (path_entry);
+
   gtk_editable_set_position (GTK_EDITABLE (path_entry), -1);
 
   gtk_widget_queue_draw (GTK_WIDGET (path_entry));
