@@ -1,4 +1,4 @@
-/* $Id$ */
+/* vi:set et ai sw=2 sts=2 ts=2: */
 /*-
  * Copyright (c) 2005-2006 Benedikt Meurer <benny@xfce.org>
  *
@@ -34,17 +34,20 @@
 #include <thunar/thunar-marshal.h>
 #include <thunar/thunar-pango-extensions.h>
 #include <thunar/thunar-text-renderer.h>
+#include <thunar/thunar-util.h>
 
 
 
 enum
 {
   PROP_0,
+  PROP_ALIGNMENT,
   PROP_FOLLOW_PRELIT,
   PROP_FOLLOW_STATE,
   PROP_TEXT,
   PROP_WRAP_MODE,
   PROP_WRAP_WIDTH,
+  N_PROPERTIES
 };
 
 enum
@@ -118,29 +121,32 @@ struct _ThunarTextRenderer
 {
   GtkCellRenderer __parent__;
 
-  PangoLayout  *layout;
-  GtkWidget    *widget;
-  gboolean      text_static;
-  gchar        *text;
-  gint          char_width;
-  gint          char_height;
-  PangoWrapMode wrap_mode;
-  gint          wrap_width;
-  gboolean      follow_state;
-  gint          focus_width;;
+  /* pango renderer properties */
+  PangoLayout    *layout;
+  GtkWidget      *widget;
+  guint           text_static : 1;
+  gchar          *text;
+  gint            char_width;
+  gint            char_height;
+  PangoWrapMode   wrap_mode;
+  gint            wrap_width;
+  guint           follow_state : 1;
+  gint            focus_width;;
+  PangoAlignment  alignment;
 
   /* underline prelited rows */
-  gboolean      follow_prelit;
+  guint           follow_prelit : 1;
 
   /* cell editing support */
-  GtkWidget    *entry;
-  gboolean      entry_menu_active;
-  gint          entry_menu_popdown_timer_id;
+  GtkWidget      *entry;
+  guint           entry_menu_active : 1;
+  guint           entry_menu_popdown_timer_id;
 };
 
 
 
-static guint text_renderer_signals[LAST_SIGNAL];
+static guint       text_renderer_signals[LAST_SIGNAL];
+static GParamSpec *text_renderer_props[N_PROPERTIES] = { NULL, };
 
 
 
@@ -164,19 +170,31 @@ thunar_text_renderer_class_init (ThunarTextRendererClass *klass)
   gtkcell_renderer_class->render = thunar_text_renderer_render;
   gtkcell_renderer_class->start_editing = thunar_text_renderer_start_editing;
 
+  /**
+   * ThunarTextRenderer:alignment:
+   *
+   * Specifies how to align the lines of text with respect to each other.
+   **/
+  text_renderer_props[PROP_ALIGNMENT] =
+      g_param_spec_enum ("alignment",
+                         "alignment",
+                         "alignment",
+                         PANGO_TYPE_ALIGNMENT,
+                         PANGO_ALIGN_LEFT,
+                         EXO_PARAM_READWRITE);
+
   /**
    * ThunarTextRenderer:follow-prelit:
    *
    * Whether to underline prelited cells. This is used for the single
    * click support in the detailed list view.
    **/
-  g_object_class_install_property (gobject_class,
-                                   PROP_FOLLOW_PRELIT,
-                                   g_param_spec_boolean ("follow-prelit",
-                                                         "follow-prelit",
-                                                         "follow-prelit",
-                                                         FALSE,
-                                                         EXO_PARAM_READWRITE));
+  text_renderer_props[PROP_FOLLOW_PRELIT] =
+      g_param_spec_boolean ("follow-prelit",
+                            "follow-prelit",
+                            "follow-prelit",
+                            FALSE,
+                            EXO_PARAM_READWRITE);
 
   /**
    * ThunarTextRenderer:follow-state:
@@ -186,26 +204,24 @@ thunar_text_renderer_class_init (ThunarTextRendererClass *klass)
    * for #ExoIconView, which doesn't draw any item state indicators
    * itself.
    **/
-  g_object_class_install_property (gobject_class,
-                                   PROP_FOLLOW_STATE,
-                                   g_param_spec_boolean ("follow-state",
-                                                         "follow-state",
-                                                         "follow-state",
-                                                         FALSE,
-                                                         EXO_PARAM_READWRITE));
+  text_renderer_props[PROP_FOLLOW_STATE] =
+      g_param_spec_boolean ("follow-state",
+                            "follow-state",
+                            "follow-state",
+                            FALSE,
+                            EXO_PARAM_READWRITE);
 
   /**
    * ThunarTextRenderer:text:
    *
    * The text to render.
    **/
-  g_object_class_install_property (gobject_class,
-                                   PROP_TEXT,
-                                   g_param_spec_string ("text",
-                                                        "text",
-                                                        "text",
-                                                        NULL,
-                                                        EXO_PARAM_READWRITE));
+  text_renderer_props[PROP_TEXT] =
+      g_param_spec_string ("text",
+                           "text",
+                           "text",
+                           NULL,
+                           EXO_PARAM_READWRITE);
 
   /**
    * ThunarTextRenderer:wrap-mode:
@@ -214,14 +230,13 @@ thunar_text_renderer_class_init (ThunarTextRendererClass *klass)
    * does not have enough room to display the entire string. This property has
    * no effect unless the wrap-width property is set.
    **/
-  g_object_class_install_property (gobject_class,
-                                   PROP_WRAP_MODE,
-                                   g_param_spec_enum ("wrap-mode",
-                                                      "wrap-mode",
-                                                      "wrap-mode",
-                                                      PANGO_TYPE_WRAP_MODE,
-                                                      PANGO_WRAP_CHAR,
-                                                      EXO_PARAM_READWRITE));
+  text_renderer_props[PROP_WRAP_MODE] =
+      g_param_spec_enum ("wrap-mode",
+                         "wrap-mode",
+                         "wrap-mode",
+                         PANGO_TYPE_WRAP_MODE,
+                         PANGO_WRAP_CHAR,
+                         EXO_PARAM_READWRITE);
 
   /**
    * ThunarTextRenderer:wrap-width:
@@ -230,13 +245,15 @@ thunar_text_renderer_class_init (ThunarTextRendererClass *klass)
    * be used to influence at what character positions the line breaks can be placed.
    * Setting wrap-width to -1 turns wrapping off.
    **/
-  g_object_class_install_property (gobject_class,
-                                   PROP_WRAP_WIDTH,
-                                   g_param_spec_int ("wrap-width",
-                                                     "wrap-width",
-                                                     "wrap-width",
-                                                     -1, G_MAXINT, -1,
-                                                     EXO_PARAM_READWRITE));
+  text_renderer_props[PROP_WRAP_WIDTH] =
+      g_param_spec_int ("wrap-width",
+                        "wrap-width",
+                        "wrap-width",
+                        -1, G_MAXINT, -1,
+                        EXO_PARAM_READWRITE);
+
+  /* install properties */
+  g_object_class_install_properties (gobject_class, N_PROPERTIES, text_renderer_props);
 
   /**
    * ThunarTextRenderer::edited:
@@ -263,7 +280,7 @@ static void
 thunar_text_renderer_init (ThunarTextRenderer *text_renderer)
 {
   text_renderer->wrap_width = -1;
-  text_renderer->entry_menu_popdown_timer_id = -1;
+  text_renderer->alignment = PANGO_ALIGN_LEFT;
 }
 
 
@@ -295,6 +312,10 @@ thunar_text_renderer_get_property (GObject    *object,
 
   switch (prop_id)
     {
+    case PROP_ALIGNMENT:
+      g_value_set_enum (value, text_renderer->alignment);
+      break;
+
     case PROP_FOLLOW_PRELIT:
       g_value_set_boolean (value, text_renderer->follow_prelit);
       break;
@@ -334,6 +355,10 @@ thunar_text_renderer_set_property (GObject      *object,
 
   switch (prop_id)
     {
+    case PROP_ALIGNMENT:
+      text_renderer->alignment = g_value_get_enum (value);
+      break;
+
     case PROP_FOLLOW_PRELIT:
       text_renderer->follow_prelit = g_value_get_boolean (value);
       break;
@@ -459,29 +484,28 @@ thunar_text_renderer_render (GtkCellRenderer     *renderer,
   GtkStateType        state;
   cairo_t            *cr;
   gint                x0, x1, y0, y1;
-  gint                text_width;
-  gint                text_height;
   gint                x_offset;
   gint                y_offset;
+  PangoRectangle      rect;
 
   /* setup the new widget */
   thunar_text_renderer_set_widget (text_renderer, widget);
 
   if ((flags & GTK_CELL_RENDERER_SELECTED) == GTK_CELL_RENDERER_SELECTED)
     {
-      if (GTK_WIDGET_HAS_FOCUS (widget))
+      if (gtk_widget_has_focus (widget))
         state = GTK_STATE_SELECTED;
       else
         state = GTK_STATE_ACTIVE;
     }
   else if ((flags & GTK_CELL_RENDERER_PRELIT) == GTK_CELL_RENDERER_PRELIT
-        && GTK_WIDGET_STATE (widget) == GTK_STATE_PRELIGHT)
+        && gtk_widget_get_state (widget) == GTK_STATE_PRELIGHT)
     {
       state = GTK_STATE_PRELIGHT;
     }
   else
     {
-      if (GTK_WIDGET_STATE (widget) == GTK_STATE_INSENSITIVE)
+      if (gtk_widget_get_state (widget) == GTK_STATE_INSENSITIVE)
         state = GTK_STATE_INSENSITIVE;
       else
         state = GTK_STATE_NORMAL;
@@ -506,24 +530,25 @@ thunar_text_renderer_render (GtkCellRenderer     *renderer,
     }
 
   pango_layout_set_text (text_renderer->layout, text_renderer->text, -1);
+  pango_layout_set_alignment (text_renderer->layout, text_renderer->alignment);
 
   /* calculate the real text dimension */
-  pango_layout_get_pixel_size (text_renderer->layout, &text_width, &text_height);
+  pango_layout_get_pixel_extents (text_renderer->layout, NULL, &rect);
 
   /* take into account the state indicator (required for calculation) */
   if (text_renderer->follow_state)
     {
-      text_width += 2 * text_renderer->focus_width;
-      text_height += 2 * text_renderer->focus_width;
+      rect.width += 2 * text_renderer->focus_width;
+      rect.height += 2 * text_renderer->focus_width;
     }
 
   /* calculate the real x-offset */
   x_offset = ((gtk_widget_get_direction (widget) == GTK_TEXT_DIR_RTL) ? (1.0 - renderer->xalign) : renderer->xalign)
-           * (cell_area->width - text_width - (2 * renderer->xpad));
+           * (cell_area->width - rect.width - (2 * renderer->xpad));
   x_offset = MAX (x_offset, 0);
 
   /* calculate the real y-offset */
-  y_offset = renderer->yalign * (cell_area->height - text_height - (2 * renderer->ypad));
+  y_offset = renderer->yalign * (cell_area->height - rect.height - (2 * renderer->ypad));
   y_offset = MAX (y_offset, 0);
 
   /* render the state indicator */
@@ -532,8 +557,8 @@ thunar_text_renderer_render (GtkCellRenderer     *renderer,
       /* calculate the text bounding box (including the focus padding/width) */
       x0 = cell_area->x + x_offset;
       y0 = cell_area->y + y_offset;
-      x1 = x0 + text_width;
-      y1 = y0 + text_height;
+      x1 = x0 + rect.width;
+      y1 = y0 + rect.height;
 
       /* Cairo produces nicer results than using a polygon
        * and so we use it directly if possible.
@@ -556,15 +581,15 @@ thunar_text_renderer_render (GtkCellRenderer     *renderer,
   /* draw the focus indicator */
   if (text_renderer->follow_state && (flags & GTK_CELL_RENDERER_FOCUSED) != 0)
     {
-      gtk_paint_focus (widget->style, window, GTK_WIDGET_STATE (widget), NULL, widget, "icon_view",
-                       cell_area->x + x_offset, cell_area->y + y_offset, text_width, text_height);
+      gtk_paint_focus (widget->style, window, gtk_widget_get_state (widget), NULL, widget, "icon_view",
+                       cell_area->x + x_offset, cell_area->y + y_offset, rect.width, rect.height);
     }
 
   /* get proper sizing for the layout drawing */
   if (text_renderer->follow_state)
     {
-      text_width -= 2 * text_renderer->focus_width;
-      text_height -= 2 * text_renderer->focus_width;
+      rect.width -= 2 * text_renderer->focus_width;
+      rect.height -= 2 * text_renderer->focus_width;
       x_offset += text_renderer->focus_width;
       y_offset += text_renderer->focus_width;
     }
@@ -572,8 +597,8 @@ thunar_text_renderer_render (GtkCellRenderer     *renderer,
   /* draw the text */
   gtk_paint_layout (widget->style, window, state, TRUE,
                     expose_area, widget, "cellrenderertext",
-                    cell_area->x + x_offset + renderer->xpad,
-                    cell_area->y + y_offset + renderer->ypad,
+                    cell_area->x + x_offset + renderer->xpad - rect.x,
+                    cell_area->y + y_offset + renderer->ypad - rect.y,
                     text_renderer->layout);
 }
 
@@ -732,7 +757,7 @@ thunar_text_renderer_grab_focus (GtkWidget          *entry,
   text = gtk_entry_get_text (GTK_ENTRY (entry));
 
   /* lookup the last dot in the text */
-  dot = strrchr (text, '.');
+  dot = thunar_util_str_get_extension (text);
   if (G_LIKELY (dot != NULL))
     {
       /* determine the UTF-8 char offset */
@@ -769,7 +794,7 @@ thunar_text_renderer_populate_popup (GtkEntry           *entry,
                                      GtkMenu            *menu,
                                      ThunarTextRenderer *text_renderer)
 {
-  if (G_UNLIKELY (text_renderer->entry_menu_popdown_timer_id >= 0))
+  if (G_UNLIKELY (text_renderer->entry_menu_popdown_timer_id != 0))
     g_source_remove (text_renderer->entry_menu_popdown_timer_id);
 
   text_renderer->entry_menu_active = TRUE;
@@ -785,7 +810,7 @@ thunar_text_renderer_popup_unmap (GtkMenu            *menu,
 {
   text_renderer->entry_menu_active = FALSE;
 
-  if (G_LIKELY (text_renderer->entry_menu_popdown_timer_id < 0))
+  if (G_LIKELY (text_renderer->entry_menu_popdown_timer_id == 0))
     {
       text_renderer->entry_menu_popdown_timer_id = g_timeout_add_full (G_PRIORITY_LOW, 500u, thunar_text_renderer_entry_menu_popdown_timer,
                                                                        text_renderer, thunar_text_renderer_entry_menu_popdown_timer_destroy);
@@ -802,7 +827,7 @@ thunar_text_renderer_entry_menu_popdown_timer (gpointer user_data)
   GDK_THREADS_ENTER ();
 
   /* check if we still have the keyboard focus */
-  if (G_UNLIKELY (!GTK_WIDGET_HAS_FOCUS (text_renderer->entry)))
+  if (G_UNLIKELY (!gtk_widget_has_focus (text_renderer->entry)))
     thunar_text_renderer_editing_done (GTK_CELL_EDITABLE (text_renderer->entry), text_renderer);
 
   GDK_THREADS_LEAVE ();
@@ -815,7 +840,7 @@ thunar_text_renderer_entry_menu_popdown_timer (gpointer user_data)
 static void
 thunar_text_renderer_entry_menu_popdown_timer_destroy (gpointer user_data)
 {
-  THUNAR_TEXT_RENDERER (user_data)->entry_menu_popdown_timer_id = -1;
+  THUNAR_TEXT_RENDERER (user_data)->entry_menu_popdown_timer_id = 0;
 }
 
 
